import {Request, Response} from 'express';
import AccessToken from '../../models/access-token';
import {log, reportError} from '../../core/utils';
import BanRecord from '../../models/ban-record';
import {plainToClass} from 'class-transformer';

export default async (req: Request, res: Response) => {
    if (req.user.roles.intBanRecordsWriter) {
        const banRecord = plainToClass(BanRecord, [req.body])[0];
        banRecord.addedBy = req.user.id;
        const errors = await banRecord.validate();
        if (errors.length) {
            res.status(400).send({
                error: 'Record validation error',
                details: errors.map(e => ({property: e.property, constraints: e.constraints}))
            });
        } else {
            const result = await banRecord.save();
            res.send({result: 'Record saved', details: result});
        }
    } else {
        res.status(403).send({error: 'Access denied'});
    }
};
