"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const db_1 = require("../core/db");
const application_model_1 = require("./application-model");
const class_validator_1 = require("class-validator");
const class_transformer_1 = require("class-transformer");
class BanRecord extends application_model_1.default {
    static new(data) {
        return class_transformer_1.plainToClass(BanRecord, data);
    }
    static getAll() {
        // TODO Maybe should have everything in camelCase for consistency
        return db_1.default.many(`
            SELECT
                uuid,
                accused_discord_id as "accusedDiscordId",
                accused_discord_username as "accusedDiscordUsername",
                added_by as "addedBy",
                case_description as "caseDescription",
                case_moderator as "caseModerator",
                case_origin as "caseOrigin",
                banned_until as "bannedUntil"
            FROM int_ban_records
            ORDER BY id ASC;
        `);
    }
    async save() {
        const errors = await this.validate();
        if (errors.length) {
            throw new Error('Record validation failed');
        }
        // TODO Use ColumnSet here
        return db_1.default.query(`
            INSERT INTO int_ban_records (
                accused_discord_id,
                accused_discord_username,
                added_by,
                case_description,
                case_moderator,
                case_origin,
                banned_until
            ) VALUES (
                $(accusedDiscordId),
                $(accusedDiscordUsername),
                $(addedBy),
                $(caseDescription),
                $(caseModerator),
                $(caseOrigin),
                $(bannedUntil)
            );
        `, Object.assign({}, {
            accusedDiscordUsername: null,
            caseDescription: null,
            caseModerator: null,
            bannedUntil: null
        }, this));
    }
}
__decorate([
    class_validator_1.IsNumber()
], BanRecord.prototype, "addedBy", void 0);
__decorate([
    class_validator_1.IsString(),
    class_validator_1.Matches(/^\d{18}$/)
], BanRecord.prototype, "accusedDiscordId", void 0);
__decorate([
    class_validator_1.IsOptional(),
    class_validator_1.IsString()
], BanRecord.prototype, "accusedDiscordUsername", void 0);
__decorate([
    class_validator_1.IsOptional(),
    class_validator_1.IsString(),
    class_validator_1.Length(2, 1000)
], BanRecord.prototype, "caseDescription", void 0);
__decorate([
    class_validator_1.IsOptional(),
    class_validator_1.IsString(),
    class_validator_1.Length(2, 20)
], BanRecord.prototype, "caseModerator", void 0);
__decorate([
    class_validator_1.IsString(),
    class_validator_1.Length(2, 100)
], BanRecord.prototype, "caseOrigin", void 0);
__decorate([
    class_validator_1.IsOptional(),
    class_validator_1.IsDateString()
], BanRecord.prototype, "bannedUntil", void 0);
exports.default = BanRecord;
//# sourceMappingURL=ban-record.js.map